scipy.stats.shapiro — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# scipy.stats.shapiro

`scipy.stats.` `shapiro`(x, a=None, reta=False)

  Perform the Shapiro-Wilk test for normality.

  The Shapiro-Wilk test tests the null hypothesis that the data was drawn from a normal distribution.

  Parameters: | x : array_like Array of sample data. a : array_like, optional Array of internal parameters used in the calculation. If these are not given, they will be computed internally. If x has length n, then a must have length n/2. reta : bool, optional Whether or not to return the internally computed a values. The default is False.
  Returns: | W : float The test statistic. p-value : float The p-value for the hypothesis test. a : array_like, optional If reta is True, then these are the internally computed “a” values that may be passed into this function on future calls.

  See also

  `anderson`
    The Anderson-Darling test for normality

  References

  [R15] | http://www.itl.nist.gov/div898/handbook/prc/section2/prc213.htm

### Navigation

- index
- STAC Release Candidate documentation »